@@ -146,6 +146,8 @@ from invenio_db import db
 
 from invenio_oauthclient.errors import OAuthCERNRejectedAccountError
 from invenio_oauthclient.handlers.rest import response_handler
+from invenio_oauthclient.handlers.utils import \
+    require_more_than_one_external_account
 from invenio_oauthclient.models import RemoteAccount
 from invenio_oauthclient.proxies import current_oauthclient
 from invenio_oauthclient.utils import oauth_link_external_id, \
@@ -389,6 +391,7 @@ def get_resource(remote):
 
 def _account_info(remote, resp):
     """Retrieve remote account information used to find local user."""
+    g.oauth_logged_in_with_remote = remote
     resource = get_resource(remote)
 
     valid_identities = current_app.config.get(
@@ -444,6 +447,7 @@ def account_info_rest(remote, resp):
         )
 
 
+@require_more_than_one_external_account
 def _disconnect(remote, *args, **kwargs):
     """Handle unlinking of remote account."""
     if not current_user.is_authenticated:
@@ -508,6 +512,11 @@ def on_identity_changed(sender, identity):
         disconnect_identity(identity)
         return
 
+    remote = g.get("oauth_logged_in_with_remote", None)
+    if not remote or remote.name != "cern":
+        # signal coming from another remote app
+        return
+
     client_id = current_app.config['CERN_APP_CREDENTIALS']['consumer_key']
     account = RemoteAccount.get(
         user_id=current_user.get_id(),
@@ -515,7 +524,6 @@ def on_identity_changed(sender, identity):
     )
     groups = []
     if account:
-        remote = find_remote_by_client_id(client_id)
         resource = get_resource(remote)
         refresh = current_app.config.get(
             'OAUTHCLIENT_CERN_REFRESH_TIMEDELTA',
