@@ -8,14 +8,11 @@
 
 """Client blueprint used to handle OAuth callbacks."""
 
-from __future__ import absolute_import
-
-from flask import Blueprint, abort, current_app, flash, redirect, request, \
-    url_for
+from flask import Blueprint, abort, current_app, redirect, request, url_for
 from flask_oauthlib.client import OAuthException
+from invenio_accounts.views import login as base_login
 from invenio_db import db
 from itsdangerous import BadData
-from werkzeug.local import LocalProxy
 
 from .._compat import _create_identifier
 from ..errors import OAuthRemoteNotFound
@@ -64,6 +61,40 @@ def post_ext_init(state):
                        'invenio_oauthclient/settings/base.html'))
 
 
+@blueprint.route("/login")
+def auto_redirect_login(*args, **kwargs):
+    """Handles automatic redirect to external auth service.
+
+    The login endpoint will redirect automatically to the external
+    auth service is the following conditions are met:
+
+    * local login is disabled
+    * redirect to external login is enabled
+    * only one external auth service is configured
+
+    This function should be set as value of the invenio-accounts
+    config var ``ACCOUNTS_LOGIN_VIEW_FUNCTION``. It should be defined in
+    the Invenio application configuration to ensure that is correctly loaded.
+    """
+    local_login_enabled = current_app.config.get(
+        "ACCOUNTS_LOCAL_LOGIN_ENABLED", False
+    )
+    auto_redirect_enabled = current_app.config.get(
+        "OAUTHCLIENT_AUTO_REDIRECT_TO_EXTERNAL_LOGIN", False
+    )
+    would_redirect = auto_redirect_enabled and not local_login_enabled
+    remote_apps = list(current_oauthclient.oauth.remote_apps)
+
+    if would_redirect and len(remote_apps) == 1:
+        # if local login is disabled and we only have one OAuth2 remote app
+        # configured, we forward directly to that
+        url = url_for("invenio_oauthclient.login", remote_app=remote_apps[0])
+        return redirect(url)
+
+    else:
+        return base_login(*args, **kwargs)
+
+
 def _login(remote_app, authorized_view_name):
     """Send user to remote application for authentication."""
     oauth = current_oauthclient.oauth
@@ -88,7 +119,6 @@ def _login(remote_app, authorized_view_name):
         'next': next_param,
         'sid': _create_identifier(),
     })
-
     return oauth.remote_apps[remote_app].authorize(
         callback=callback_url,
         state=state_token,
