@@ -8,8 +8,6 @@
 
 """Test case for CERN oauth remote app_rest."""
 
-from __future__ import absolute_import
-
 import os
 from datetime import timedelta
 
@@ -17,6 +15,7 @@ import pytest
 from flask import current_app, g, session, url_for
 from flask_login import current_user
 from flask_security import login_user, logout_user
+from flask_security.utils import hash_password
 from helpers import check_response_redirect_url_args, get_state, \
     mock_remote_get, mock_response
 from six.moves.urllib_parse import parse_qs, urlparse
@@ -119,12 +118,16 @@ def test_account_setup(app_rest, example_cern_openid_rest, models_fixture):
 
     datastore = app_rest.extensions['invenio-accounts'].datastore
     user = datastore.find_user(email='john.doe@cern.ch')
+    user.password = hash_password("1234")
     assert user
 
     with app_rest.test_request_context():
         resp = disconnect_rest_handler(ioc.remote_apps['cern_openid'])
         assert resp.status_code >= 300
 
+        # simulate login (account_info fetch)
+        g.oauth_logged_in_with_remote = ioc.remote_apps['cern_openid']
+
         login_user(user)
         assert len(g.identity.provides) == 3
 
@@ -134,6 +137,7 @@ def test_account_setup(app_rest, example_cern_openid_rest, models_fixture):
         assert OAUTHCLIENT_CERN_OPENID_SESSION_KEY not in session
 
         # Login again to test the disconnect handler
+        g.oauth_logged_in_with_remote = ioc.remote_apps['cern_openid']
         login_user(user)
         assert len(g.identity.provides) == 3
 
@@ -192,6 +196,7 @@ def test_account_info_not_allowed_account(app_rest, example_cern_openid_rest):
 
     mock_remote_get(ioc, 'cern_openid', example_response)
     resp = account_info_rest(ioc.remote_apps['cern_openid'], None)
+    assert g.oauth_logged_in_with_remote == ioc.remote_apps['cern_openid']
 
     assert resp.status_code == 302
     expected_url_args = {
