@@ -37,8 +37,11 @@ def test_account_info(app_rest, example_orcid):
         ioc.remote_apps['orcid'], example_data) == example_account_info
 
     assert account_info(ioc.remote_apps['orcid'], {}) == \
-        dict(external_id=None, external_method='orcid', user=dict(profile=dict(
-            full_name=None)))
+        dict(
+            external_id=None,
+            external_method='orcid',
+            user=dict(profile=dict(full_name=None))
+        )
 
 
 def test_login(app_rest, example_orcid):
@@ -81,7 +84,6 @@ def test_authorized_signup(app_rest_with_userprofiles,
                     state=get_state('orcid')))
         assert resp.status_code == 302
         assert resp.location == (
-            'http://localhost' +
             url_for('invenio_oauthclient.rest_signup', remote_app='orcid')
         )
 
@@ -96,6 +98,7 @@ def test_authorized_signup(app_rest_with_userprofiles,
             'password': '123456',
             'profile.username': 'pippo',
             'profile.full_name': account_info['user']['profile']['full_name'],
+            'profile.affiliations': 'CERN'
         }
 
         # Mock request to ORCID to get user bio.
@@ -121,8 +124,7 @@ def test_authorized_signup(app_rest_with_userprofiles,
             method='orcid', id_user=user.id,
             id=example_data['orcid']
         ).one()
-        # FIXME see contrib/orcid.py line 167
-        assert user.profile.full_name == 'Josiah Carberry'
+        assert user.user_profile["full_name"] == 'Josiah Carberry'
         #  assert user.given_names == 'Josiah'
         #  assert user.family_name == 'Carberry'
         # check that the user's email is not yet validated
